@@ -6,5 +6,5 @@ from .context.context.context import Context, root
 from .model import Model, poll, secs, mins, hours, days, months, dow, Init
 from .modifiers.state import private, public
 from .event import Event
-from .sdk import spiodirect
+from .sdk import spiodirect, ncaab, mlb
 from .structs.table import Table
\ No newline at end of file
