@@ -57,6 +57,7 @@ class Model(Modellike):
     handler_loops : Dict[str, asyncio.BaseEventLoop] = {}
     cron_events : Dict[str, type[CronEvent]] = {}
     cron_logs : Dict[str, int] = {}
+    cron_queue : List[int] = []
 
     cron_pool = concurrent.futures.ThreadPoolExecutor()
     task_listener_pool = concurrent.futures.ThreadPoolExecutor()
@@ -76,6 +77,7 @@ class Model(Modellike):
     history : bool = False
 
 
+
     def __init__(self, /, *, 
             store : redis.Redis = r, 
             cron_window : int = 1,
@@ -431,6 +433,9 @@ class Model(Modellike):
                     frontier.remove(key)
 
           
+    def retrodate_emit(self, *, event=CronEvent):
+        pass
+          
     def run_retrodate(self, start : float):
         
         flag = True
