@@ -1,6 +1,7 @@
 import unittest
 from .lru import lru_cache_time
 import time
+import datetime
 
 
 class LruTest(unittest.TestCase):
@@ -19,8 +20,13 @@ class LruTest(unittest.TestCase):
             self.assertEquals(count, 1)
         
         time.sleep(1)
-        self.assertEquals(multiply(2, 2), 4)
-        self.assertEquals(count, 2)
+        for i in range(10):
+            self.assertEquals(multiply(2, 2), 4)
+            self.assertEquals(count, 2)
+        
+    def test_lru_datetime(self):
+        
+       pass
         
         
         
\ No newline at end of file
